/**
 ******************************************************************************
 *
 * @file        MG82F6D64_INT_VECTOR.c
 *
 * @brief       This is the C code format main file.
 *
 * @par         Project
 *              MG82F6D64
 * @version     V1.01
 * @date        2020/12/07
 * @copyright   Copyright (c) 2019 MegaWin Technology Co., Ltd.
 *              All rights reserved.
 *
 ******************************************************************************
 * @par         Disclaimer
 *      The Demo software is provided "AS IF"  without any warranty, either
 *      expressed or implied, including, but not limited to, the implied warranties
 *      of merchantability and fitness for a particular purpose.  The author will
 *      not be liable for any special, incidental, consequential or indirect
 *      damages due to loss of data or any other reason.
 *      These statements agree with the world wide and local dictated laws about
 *      authorship and violence against these laws.
 ******************************************************************************
 ******************************************************************************
 */

#include "MG82F6D64_CONFIG.h"

/**
 *******************************************************************************
 * Interrupts ISR
 *******************************************************************************
 */
 
/// @cond __DRV_Wizard_Without_Doxygen
#if MG82F6D64_INT_ALL_WIZARD
/// @endcond
 
 
/**
 *******************************************************************************
 * @brief       External Interrupt 0 Vector Service Routine
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    ExINT0_IE0_ISR();
 * @endcode
 *******************************************************************************
 */
/// @cond __DRV_Wizard_Without_Doxygen
#if MG82F6D64_INT0_EN
/// @endcond
void ExINT0_IE0_ISR(void)  interrupt INT0_ISR_VECTOR
{
    _push_(SFRPI);
    __DRV_INT0_ClearFlag();
    _pop_(SFRPI);
}
/// @cond __DRV_Wizard_Without_Doxygen
#endif
/// @endcond


/**
 *******************************************************************************
 * @brief       Timer 0 Interrupt Vector Service Routine
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    TIMER0_TF0_ISR();
 * @endcode
 *******************************************************************************
 */
/// @cond __DRV_Wizard_Without_Doxygen
#if MG82F6D64_TIMER0_IT_EN
/// @endcond
void TIMER0_TF0_ISR(void)   interrupt TIMER0_ISR_VECTOR
{
    _push_(SFRPI);

    _pop_(SFRPI);
}
/// @cond __DRV_Wizard_Without_Doxygen
#endif
/// @endcond



/**
 *******************************************************************************
 * @brief       External Interrupt 1 Vector Service Routine
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    ExINT1_IE1_ISR();
 * @endcode
 *******************************************************************************
 */
/// @cond __DRV_Wizard_Without_Doxygen
#if MG82F6D64_INT1_EN
/// @endcond
void ExINT1_IE1_ISR(void)   interrupt INT1_ISR_VECTOR
{
    _push_(SFRPI);
    __DRV_INT1_ClearFlag();
    _pop_(SFRPI);
}
/// @cond __DRV_Wizard_Without_Doxygen
#endif
/// @endcond



/**
 *******************************************************************************
 * @brief       Timer 1 Interrupt Vector Service Routine
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    TIMER1_TF1_ISR();
 * @endcode
 *******************************************************************************
 */
/// @cond __DRV_Wizard_Without_Doxygen
#if MG82F6D64_TIMER1_IT_EN
/// @endcond
void TIMER1_TF1_ISR(void)   interrupt TIMER1_ISR_VECTOR
{
    _push_(SFRPI);

    _pop_(SFRPI);
}
/// @cond __DRV_Wizard_Without_Doxygen
#endif
/// @endcond



/**
 *******************************************************************************
 * @brief       UART0 Interrupt Vector Service Routine
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    UART0_RI0_TI0_ISR();
 * @endcode
 *******************************************************************************
 */
/// @cond __DRV_Wizard_Without_Doxygen
#if MG82F6D64_S0_IT_EN
/// @endcond
void UART0_RI0_TI0_ISR(void)   interrupt S0_ISR_VECTOR
{
    _push_(SFRPI);

    _pop_(SFRPI);
}
/// @cond __DRV_Wizard_Without_Doxygen
#endif
/// @endcond



/**
 *******************************************************************************
 * @brief       Timer 2 Interrupt Vector Service Routine
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    TIMER2_TF2_EXF2_TF2L_ISR();
 * @endcode
 *******************************************************************************
 */
/// @cond __DRV_Wizard_Without_Doxygen
#if MG82F6D64_TIMER2_IT_EN
/// @endcond
void TIMER2_TF2_EXF2_TF2L_ISR(void)   interrupt TIMER2_ISR_VECTOR
{
    _push_(SFRPI);

    _pop_(SFRPI);
}
/// @cond __DRV_Wizard_Without_Doxygen
#endif
/// @endcond



/**
 *******************************************************************************
 * @brief       External Interrupt 2 Vector Service Routine
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    ExINT2_IE2_ISR();
 * @endcode
 *******************************************************************************
 */
/// @cond __DRV_Wizard_Without_Doxygen
#if MG82F6D64_INT2_EN
/// @endcond
void ExINT2_IE2_ISR(void)   interrupt INT2_ISR_VECTOR
{
    _push_(SFRPI);
    __DRV_INT2_ClearFlag();
    _pop_(SFRPI);
}
/// @cond __DRV_Wizard_Without_Doxygen
#endif
/// @endcond



/**
 *******************************************************************************
 * @brief       SPI Interrupt Vector Service Routine
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    SPI_SPIF_ISR();
 * @endcode
 *******************************************************************************
 */
/// @cond __DRV_Wizard_Without_Doxygen
#if MG82F6D64_SPI_IT_EN
/// @endcond
void SPI_SPIF_ISR(void)   interrupt SPI_ISR_VECTOR
{
    _push_(SFRPI);

    _pop_(SFRPI);
}
/// @cond __DRV_Wizard_Without_Doxygen
#endif
/// @endcond



/**
 *******************************************************************************
 * @brief       ADC Interrupt Vector Service Routine
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    ADC_ADCI_ISR();
 * @endcode
 *******************************************************************************
 */
/// @cond __DRV_Wizard_Without_Doxygen
#if MG82F6D64_ADC_IT_EN
/// @endcond
void ADC_ADCI_ISR(void)   interrupt ADC_ISR_VECTOR
{
    _push_(SFRPI);

    _pop_(SFRPI);
}
/// @cond __DRV_Wizard_Without_Doxygen
#endif
/// @endcond



/**
 *******************************************************************************
 * @brief       PCA 0 Interrupt Vector Service Routine
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    PCA0_CF_CCFn_ISR();
 * @endcode
 *******************************************************************************
 */
/// @cond __DRV_Wizard_Without_Doxygen
#if MG82F6D64_PCA_IT_EN
/// @endcond
void PCA0_CF_CCFn_ISR(void)   interrupt PCA0_ISR_VECTOR
{
    _push_(SFRPI);

    _pop_(SFRPI);
}
/// @cond __DRV_Wizard_Without_Doxygen
#endif
/// @endcond



/**
 *******************************************************************************
 * @brief       System Flag Interrupt Vector Service Routine
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    SYSFlag_ISR();
 * @endcode
 *******************************************************************************
 */
/// @cond __DRV_Wizard_Without_Doxygen
#if MG82F6D64_SYSFLAG_EN
/// @endcond
void SYSFlag_ISR()  interrupt SYSFLAG_ISR_VECTOR
{
    _push_(SFRPI);
        
    //WDT Interrupt Service Routine
    #if MG82F6D64_WDT_IT_EN
    __DRV_WDT_ClearFlag();
    #endif
    
    //RTC Interrupt Service Routine
    #if MG82F6D64_RTC_IT_EN
    __DRV_RTC_ClearFlag();
    #endif
    
    //BOD0 Interrupt Service Routine
    #if MG82F6D64_BOD0_IT_EN
    __DRV_BODx_BOD0_ClearFlag();
    #endif
    
    //BOD1 Interrupt Service Routine
    #if MG82F6D64_BOD1_IT_EN
    __DRV_BODx_BOD1_ClearFlag();
    #endif
    
    //SI2C Interrupt Service Routine
    #if MG82F6D64_SI2C_IT_EN
    if (__DRV_SI2C_GetStartFlag())
    {
        __DRV_SI2C_ClearStartFlag();
    }
    if (__DRV_SI2C_GetStopFlag())
    {
        __DRV_SI2C_ClearStopFlag();
    }
    #endif
    
    _pop_(SFRPI);
}
/// @cond __DRV_Wizard_Without_Doxygen
#endif
/// @endcond



/**
 *******************************************************************************
 * @brief       KBI Interrupt Vector Service Routine
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    KBI_KBIF_ISR();
 * @endcode
 *******************************************************************************
 */
/// @cond __DRV_Wizard_Without_Doxygen
#if MG82F6D64_KBI_EN
/// @endcond
void KBI_KBIF_ISR()  interrupt KBI_ISR_VECTOR
{
    _push_(SFRPI);
    __DRV_KBI_ClearFlag();
    _pop_(SFRPI);
}
/// @cond __DRV_Wizard_Without_Doxygen
#endif
/// @endcond



/**
 *******************************************************************************
 * @brief       I2C0 Interrupt Vector Service Routine
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    I2C0_SI_ISR();
 * @endcode
 *******************************************************************************
 */
/// @cond __DRV_Wizard_Without_Doxygen
#if MG82F6D64_I2C0_IT_EN
/// @endcond
void I2C0_SI_ISR(void)   interrupt I2C0_ISR_VECTOR
{
    _push_(SFRPI);
    Sample_I2C0_ISR_Handle();
    _pop_(SFRPI);
}
/// @cond __DRV_Wizard_Without_Doxygen
#endif
/// @endcond


/**
 *******************************************************************************
 * @brief       AC0 Interrupt Vector Service Routine
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    AC0_AC0F_ISR();
 * @endcode
 *******************************************************************************
 */
/// @cond __DRV_Wizard_Without_Doxygen
#if MG82F6D64_AC0_IT_EN
/// @endcond
void AC0_AC0F_ISR(void)   interrupt AC0_ISR_VECTOR
{
    _push_(SFRPI);
    __DRV_AC0_ClearFlag();
    _pop_(SFRPI);
}
/// @cond __DRV_Wizard_Without_Doxygen
#endif
/// @endcond


/**
 *******************************************************************************
 * @brief       UART1 Interrupt Vector Service Routine
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    UART1_RI1_STI1_ISR();
 * @endcode
 *******************************************************************************
 */
/// @cond __DRV_Wizard_Without_Doxygen
#if MG82F6D64_S1_IT_EN
/// @endcond
void UART1_RI1_STI1_ISR(void)   interrupt S1_ISR_VECTOR
{
    _push_(SFRPI);

    _pop_(SFRPI);
}
/// @cond __DRV_Wizard_Without_Doxygen
#endif
/// @endcond


/**
 *******************************************************************************
 * @brief       External Interrupt 3 Vector Service Routine
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    ExINT3_IE3_ISR();
 * @endcode
 *******************************************************************************
 */
/// @cond __DRV_Wizard_Without_Doxygen
#if MG82F6D64_INT3_EN
/// @endcond
void ExINT3_IE3_ISR(void)   interrupt INT3_ISR_VECTOR
{
    _push_(SFRPI);
    __DRV_INT3_ClearFlag();
    _pop_(SFRPI);
}
/// @cond __DRV_Wizard_Without_Doxygen
#endif
/// @endcond


/**
 *******************************************************************************
 * @brief       Timer 3 Interrupt Vector Service Routine
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    TIMER3_TF3_EXF3_TF3L_ISR();
 * @endcode
 *******************************************************************************
 */
/// @cond __DRV_Wizard_Without_Doxygen
#if MG82F6D64_TIMER3_IT_EN
/// @endcond
void TIMER3_TF3_EXF3_TF3L_ISR(void)   interrupt TIMER3_ISR_VECTOR
{
    _push_(SFRPI);

    _pop_(SFRPI);
}
/// @cond __DRV_Wizard_Without_Doxygen
#endif
/// @endcond


/**
 *******************************************************************************
 * @brief       AC1 Interrupt Vector Service Routine
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    AC1_AC1F_ISR();
 * @endcode
 *******************************************************************************
 */
/// @cond __DRV_Wizard_Without_Doxygen
#if MG82F6D64_AC1_IT_EN
/// @endcond
void AC1_AC1F_ISR(void)   interrupt AC1_ISR_VECTOR
{
    _push_(SFRPI);
    __DRV_AC1_ClearFlag();
    _pop_(SFRPI);
}
/// @cond __DRV_Wizard_Without_Doxygen
#endif
/// @endcond



/**
 *******************************************************************************
 * @brief       DMA Interrupt Vector Service Routine
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    DMA_DCF0_ISR();
 * @endcode
 *******************************************************************************
 */
/// @cond __DRV_Wizard_Without_Doxygen
#if MG82F6D64_DMA_IT_EN
/// @endcond
void DMA_DCF0_ISR(void)   interrupt DMA_ISR_VECTOR
{
    _push_(SFRPI);
    __DRV_DMA_ClearCompleteFlag();
    
//    if (TF5)
//        DRV_TIMER5_ClearTF5(); 
//    if (TF6)
//        DRV_TIMER5_ClearTF6();
    
    
    
    _pop_(SFRPI);
}
/// @cond __DRV_Wizard_Without_Doxygen
#endif
/// @endcond



/**
 *******************************************************************************
 * @brief       AC2 Interrupt Vector Service Routine
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    AC2_AC2F_ISR();
 * @endcode
 *******************************************************************************
 */
/// @cond __DRV_Wizard_Without_Doxygen
#if MG82F6D64_AC2_IT_EN
/// @endcond
void AC2_AC2F_ISR(void)   interrupt AC2_ISR_VECTOR
{
    _push_(SFRPI);
    __DRV_AC2_ClearFlag();
    _pop_(SFRPI);
}
/// @cond __DRV_Wizard_Without_Doxygen
#endif
/// @endcond




/**
 *******************************************************************************
 * @brief       UART2 Interrupt Vector Service Routine
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    UART2_RI2_TI2_ISR();
 * @endcode
 *******************************************************************************
 */
/// @cond __DRV_Wizard_Without_Doxygen
#if MG82F6D64_S2_IT_EN
/// @endcond
void UART2_RI2_TI2_ISR(void)   interrupt S2_ISR_VECTOR
{
    _push_(SFRPI);

    _pop_(SFRPI);
}
/// @cond __DRV_Wizard_Without_Doxygen
#endif
/// @endcond


/**
 *******************************************************************************
 * @brief       Timer 4 Interrupt Vector Service Routine
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    TIMER4_TF4_EXF4_TF4L_ISR();
 * @endcode
 *******************************************************************************
 */
/// @cond __DRV_Wizard_Without_Doxygen
#if MG82F6D64_TIMER4_IT_EN
/// @endcond
void TIMER4_TF4_EXF4_TF4L_ISR(void)   interrupt TIMER4_ISR_VECTOR
{
    _push_(SFRPI);

    _pop_(SFRPI);
}
/// @cond __DRV_Wizard_Without_Doxygen
#endif
/// @endcond

/**
 *******************************************************************************
 * @brief       UART3 Interrupt Vector Service Routine
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    UART3_RI3_TI3_ISR();
 * @endcode
 *******************************************************************************
 */
/// @cond __DRV_Wizard_Without_Doxygen
#if MG82F6D64_S3_IT_EN
/// @endcond
void UART3_RI3_TI3_ISR(void)   interrupt S3_ISR_VECTOR
{
    _push_(SFRPI);

    _pop_(SFRPI);
}
/// @cond __DRV_Wizard_Without_Doxygen
#endif
/// @endcond


/**
 *******************************************************************************
 * @brief       I2C1 Interrupt Vector Service Routine
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    I2C1_SI1_ISR();
 * @endcode
 *******************************************************************************
 */
/// @cond __DRV_Wizard_Without_Doxygen
#if MG82F6D64_I2C1_IT_EN
/// @endcond
void I2C1_SI1_ISR(void)   interrupt I2C1_ISR_VECTOR
{
    _push_(SFRPI);
    Sample_I2C1_ISR_Handle();
    _pop_(SFRPI);
}
/// @cond __DRV_Wizard_Without_Doxygen
#endif
/// @endcond


/// @cond __DRV_Wizard_Without_Doxygen
#endif
/// @endcond


